@@ -6,9 +6,14 @@
 
    Common utility functions.
  -}
-module Distribution.Gentoo.Util where
+module Distribution.Gentoo.Util
+       ( BSFilePath
+       , concatMapM
+       , breakAll
+       , getDirectoryContents'
+       ) where
 
-import Data.List(groupBy)
+import qualified Data.List as L
 import Data.ByteString.Char8(ByteString)
 import System.Directory(getDirectoryContents)
 import Control.Monad(liftM)
@@ -20,9 +25,10 @@ concatMapM   :: (a -> IO [b]) -> [a] -> IO [b]
 concatMapM f = liftM concat . mapM f
 
 breakAll   :: (a -> Bool) -> [a] -> [[a]]
-breakAll p = groupBy (const (not . p))
+breakAll p = L.groupBy (const (not . p))
 
 -- Don't return . or ..
 getDirectoryContents'     :: FilePath -> IO [FilePath]
-getDirectoryContents' dir = do is <- getDirectoryContents dir
-                               return $ filter (`notElem` [".", ".."]) is
+getDirectoryContents' dir = do
+    is <- getDirectoryContents dir
+    return $ filter (`notElem` [".", ".."]) $ L.sort is
